@@ -27,8 +27,9 @@ typedef struct _CbClassRec {
 typedef struct _CbRec {
 	CorePart	core;
 	Pixel		fgnd;
-	XFontStruct	*font;
+	XFontSet	fontset;
 	int		font_width;
+	int		font_ascent;
 	int		font_height;
 	GC		gc;
 	GC		gc_inv;
